---
title: <span class="badge object-type-scalar"></span> MetersPerSecond
---
# <span class="badge object-type-scalar"></span> MetersPerSecond

Velocity: meters/second (m/s)

## Definition

```python
# Velocity: meters/second (m/s)
MetersPerSecond: typing.Literal["velocityms"] = "velocityms"
```
